@@ -1,10 +1,14 @@
-pub mod node;
 pub mod tree;
+
+#[cfg(feature = "text")]
+pub mod text;
 pub mod flexbox;
 pub mod geometry;
 pub mod bitmap;
 pub mod application;
 
+pub use application::Application;
+
 pub use geometry::Point;
 pub use geometry::Size;
 
